---
title: Virtualization
page_title: Virtualization - AutoComplete - Kendo UI for Vue
description: "Use the virtualization features of the Kendo UI AutoComplete wrapper for Vue which allow you to handle large datasets."
slug: virtualization_autocomplete
position: 4
---

# Virtualization

Virtualization allows you to display large sets of data.

Regardless of the dataset size, the UI virtualization technique uses a fixed amount of list items in the popup list of the component. When the list is scrolled, the AutoComplete reuses the existing items to display the relevant data instead of creating new data.

The following example demonstrates how to set the minimum configuration of the AutoComplete and the DataSource to enable the virtualization.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-datasource ref="datasource"
                      :type="'odata'"
                      :transport-read-url="'https://demos.telerik.com/kendo-ui/service/Northwind.svc/Orders'"
                      :schema-model-fileds="fields"
                      :server-filtering="true"
                      :server-paging="true"
                      :page-size="40">
    </kendo-datasource>
    <kendo-autocomplete :data-source-ref="'datasource'"
                        :data-text-field="'ShipName'"
                        :virtual-item-height="26"
                        :template="itemTemplate"
                        :height="260"
                        style="width:400px;">
    </kendo-autocomplete>
</div>
```
```js
Vue.use(DropdownsInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp",
    data: {
        fields: {
            OrderID: { type: 'number' },
            Freight: { type: 'number' },
            ShipName: { type: 'string' },
            OrderDate: { type: 'date' },
            ShipCity: { type: 'string' }
        },
        itemTemplate: '<strong>#= OrderID #</strong> - #= ShipName #, #= ShipCountry #'
    }
})
```

## Suggested Links

* [Kendo UI AutoComplete for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/autocomplete/overview)
* [API Reference of the AutoComplete Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/autocomplete)
