---
title: Cascading ComboBoxes
page_title: Cascading ComboBoxes - ComboBox - Kendo UI for Vue
description: "Filter a Kendo UI ComboBox wrapper for Vue according to the selection in another ComboBox."
slug: cascading_combobox
position: 6
---

# Cascading ComboBoxes

The cascading ComboBox is a series of two or more ComboBoxes in which each ComboBox is filtered according to the selected options in the previous ComboBox.

To configure the cascading dependency, use the `:cascade=from` prop.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-datasource ref="datasource1"
                        :type="'odata'"
                        :server-filtering="true"
                        :transport-read-url="'https://demos.telerik.com/kendo-ui/service/Northwind.svc/Categories'">
    </kendo-datasource>
    <kendo-combobox id="categories"
                    :data-source-ref="'datasource1'"
                    :filter="'contains'"
                    :data-text-field="'CategoryName'"
                    :data-value-field="'CategoryID'">
    </kendo-combobox>
    <br/>
    <br/>
    <kendo-datasource ref="datasource2"
                        :type="'odata'"
                        :server-filtering="true"
                        :transport-read-url="'https://demos.telerik.com/kendo-ui/service/Northwind.svc/Products'">
    </kendo-datasource>
    <kendo-combobox disabled="disabled"
                    :data-source-ref="'datasource2'"
                    :auto-bind="false"
                    :cascade-from="'categories'"
                    :filter="'contains'"
                    :data-text-field="'ProductName'"
                    :data-value-field="'ProductID'">
    </kendo-combobox>
</div>
```
```js
Vue.use(DropdownsInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp"
})
```

## Suggested Links

* [Kendo UI ComboBox for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/combobox/overview)
* [API Reference of the ComboBox Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/combobox)
